/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_bass_loudness.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_bass_loudness.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_bass_loudness.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14DbBassLoudnessE_t {};
} // unnamed namespace

template <> constexpr inline auto DbBassLoudness::qt_create_metaobjectdata<qt_meta_tag_ZN14DbBassLoudnessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbBassLoudness",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "loudnessChanged",
        "outputChanged",
        "linkChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "loudness",
        "isLoudnessImmutable",
        "defaultLoudnessValue",
        "output",
        "isOutputImmutable",
        "defaultOutputValue",
        "link",
        "isLinkImmutable",
        "defaultLinkValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loudnessChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(16, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(18, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(19, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(21, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loudness'
        QtMocHelpers::PropertyData<double>(22, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isLoudnessImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLoudnessValue'
        QtMocHelpers::PropertyData<double>(24, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'output'
        QtMocHelpers::PropertyData<double>(25, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isOutputImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputValue'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'link'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isLinkImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkValue'
        QtMocHelpers::PropertyData<double>(30, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbBassLoudness, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbBassLoudness::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DbBassLoudnessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DbBassLoudnessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14DbBassLoudnessE_t>.metaTypes,
    nullptr
} };

void DbBassLoudness::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbBassLoudness *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->loudnessChanged(); break;
        case 4: _t->outputChanged(); break;
        case 5: _t->linkChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbBassLoudness::*)()>(_a, &DbBassLoudness::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbBassLoudness::*)()>(_a, &DbBassLoudness::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbBassLoudness::*)()>(_a, &DbBassLoudness::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbBassLoudness::*)()>(_a, &DbBassLoudness::loudnessChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbBassLoudness::*)()>(_a, &DbBassLoudness::outputChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbBassLoudness::*)()>(_a, &DbBassLoudness::linkChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->loudness(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isLoudnessImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultLoudnessValue(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->output(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isOutputImmutable(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->defaultOutputValue(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->link(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isLinkImmutable(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->defaultLinkValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setLoudness(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setOutput(*reinterpret_cast<double*>(_v)); break;
        case 15: _t->setLink(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbBassLoudness::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbBassLoudness::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DbBassLoudnessE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbBassLoudness::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void DbBassLoudness::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbBassLoudness::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbBassLoudness::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbBassLoudness::loudnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbBassLoudness::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbBassLoudness::linkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
