/****************************************************************************
** Meta object code from reading C++ file 'gate.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.7/src/gate.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gate.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4GateE_t {};
} // unnamed namespace

template <> constexpr inline auto Gate::qt_create_metaobjectdata<qt_meta_tag_ZN4GateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gate",
        "QML.Element",
        "BackendGate",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Use the c++ instance",
        "getReductionLevelLeft",
        "",
        "getReductionLevelRight",
        "getSideChainLevelLeft",
        "getSideChainLevelRight",
        "getCurveLevelLeft",
        "getCurveLevelRight",
        "getEnvelopeLevelLeft",
        "getEnvelopeLevelRight",
        "getAttackZoneStart",
        "getAttackThreshold",
        "getReleaseZoneStart",
        "getReleaseThreshold"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'getReductionLevelLeft'
        QtMocHelpers::MethodData<float() const>(7, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getReductionLevelRight'
        QtMocHelpers::MethodData<float() const>(9, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getSideChainLevelLeft'
        QtMocHelpers::MethodData<float() const>(10, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getSideChainLevelRight'
        QtMocHelpers::MethodData<float() const>(11, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getCurveLevelLeft'
        QtMocHelpers::MethodData<float() const>(12, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getCurveLevelRight'
        QtMocHelpers::MethodData<float() const>(13, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getEnvelopeLevelLeft'
        QtMocHelpers::MethodData<float() const>(14, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getEnvelopeLevelRight'
        QtMocHelpers::MethodData<float() const>(15, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getAttackZoneStart'
        QtMocHelpers::MethodData<float() const>(16, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getAttackThreshold'
        QtMocHelpers::MethodData<float() const>(17, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getReleaseZoneStart'
        QtMocHelpers::MethodData<float() const>(18, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getReleaseThreshold'
        QtMocHelpers::MethodData<float() const>(19, 8, QMC::AccessPublic, QMetaType::Float),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Gate, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Gate::staticMetaObject = { {
    QMetaObject::SuperData::link<PluginBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4GateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4GateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4GateE_t>.metaTypes,
    nullptr
} };

void Gate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Gate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { float _r = _t->getReductionLevelLeft();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 1: { float _r = _t->getReductionLevelRight();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 2: { float _r = _t->getSideChainLevelLeft();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 3: { float _r = _t->getSideChainLevelRight();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 4: { float _r = _t->getCurveLevelLeft();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 5: { float _r = _t->getCurveLevelRight();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 6: { float _r = _t->getEnvelopeLevelLeft();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 7: { float _r = _t->getEnvelopeLevelRight();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 8: { float _r = _t->getAttackZoneStart();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 9: { float _r = _t->getAttackThreshold();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 10: { float _r = _t->getReleaseZoneStart();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 11: { float _r = _t->getReleaseThreshold();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Gate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4GateE_t>.strings))
        return static_cast<void*>(this);
    return PluginBase::qt_metacast(_clname);
}

int Gate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PluginBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
